BadiMonth

Enum BadiMonth 

pub enum BadiMonth {
    Month(u8),
    AyyamIHa,
}
Represents one of the 19 Bahá’í months or Ayyám-i-Há

Variants



Month(u8)

One of the 19 Badi/Bahá’í months (parameter is 1-based month number)



AyyamIHa

The intercalary days of Ayyám-i-Há

Implementations

Source

impl BadiMonth

pub fn first() -> Self

First month of the year (Bahá)

pub fn last() -> Self

Last month of the year (ʻAláʼ)

pub fn next(&self) -> Option<Self>

Next month of the year (None if self is ʻAláʼ)

pub fn previous(&self) -> Option<Self>

Previous month of the year (None if self is Bahá)

pub fn validate(&self) -> Result<Self, BadiDateError>

Return self if month is valid, otherwise BadiDateError::MonthInvalid

pub fn number_of_days(&self, year: u8) -> u16

Max number of days in the month (year required to compute Ayyám-i-Há days)

pub fn arabic(&self) -> String

Arabic name of the month in the Arabic charater set

pub fn english(&self) -> String

English name of the month (as opposed to transliteration)

pub fn transliteration(&self) -> String

English transliteration of Arabic name of the month

pub fn additional_meanings(&self) -> String

Additional meanings in authorized English translations of Baháʼí scripture https://en.wikipedia.org/wiki/Bah%C3%A1%CA%BC%C3%AD_calendar

pub fn name(&self, locale: &str) -> String

Get name of the month in a locale (see /locales/app.yaml): en: English ar: Arabic tl: English transliteration extra: Additional meanings (English)

pub fn description(&self) -> String

Get a (debug) description of the month