Enum badi_date::BadiDateError
source · pub enum BadiDateError {
DayInvalid(BadiMonth, u16, u16),
MonthInvalid(BadiMonth),
DateNotSupported,
}Expand description
Error returned from trying to construct a BadiDateLike with invalid parameters
Variants
DayInvalid(BadiMonth, u16, u16)
! The day number passed in for a given BadiMonth is invalid for that month
MonthInvalid(BadiMonth)
! The BadiMonth itself is invalid (due to an invalid day number)
DateNotSupported
! The date passed in is not in the supported range
Implementations
sourceimpl BadiDateError
impl BadiDateError
sourcepub fn message(&self) -> String
pub fn message(&self) -> String
Message associated with the BadiDateError