Enum badi_date::BadiMonth

source ·
pub enum BadiMonth {
    Month(u8),
    AyyamIHa,
}
Represents one of the 19 Bahá’í months or Ayyám-i-Há

Variants



Month(u8)

One of the 19 Badi/Bahá’í months (parameter is 1-based month number)



AyyamIHa

The intercalary days of Ayyám-i-Há

Implementations

source

impl BadiMonth

source

pub fn first() -> Self

First month of the year (Bahá)

source

pub fn last() -> Self

Last month of the year (ʻAláʼ)

source

pub fn next(&self) -> Option<Self>

Next month of the year (None if self is ʻAláʼ)

source

pub fn previous(&self) -> Option<Self>

Previous month of the year (None if self is Bahá)

source

pub fn validate(&self) -> Result<Self, BadiDateError>

Return self if month is valid, otherwise BadiDateError::MonthInvalid

source

pub fn number_of_days(&self, year: u8) -> u16

Max number of days in the month (year required to compute Ayyám-i-Há days)

source

pub fn arabic(&self) -> String

Arabic name of the month in the Arabic charater set

source

pub fn english(&self) -> String

English name of the month (as opposed to transliteration)

source

pub fn transliteration(&self) -> String

English transliteration of Arabic name of the month

source

pub fn additional_meanings(&self) -> String

Additional meanings in authorized English translations of Baháʼí scripture https://en.wikipedia.org/wiki/Bah%C3%A1%CA%BC%C3%AD_calendar

source

pub fn name(&self, locale: &str) -> String

Get name of the month in a locale (see /locales/app.yaml): en: English ar: Arabic tl: English transliteration extra: Additional meanings (English)

source

pub fn description(&self) -> String

Get a (debug) description of the month